@@ -22,6 +22,7 @@
 #include <QDBusMetaType>
 #include <QDebug>
 #include <QHash>
+#include "imapparser_p.h"
 
 using namespace Akonadi;
 
@@ -50,7 +51,7 @@ class NotificationMessage::Private : public QSharedData
       parts = other.parts;
     }
 
-    bool compareWithoutOp( const Private &other ) const
+    bool compareWithoutOpAndParts( const Private &other ) const
     {
       return sessionId == other.sessionId
           && type == other.type
@@ -59,7 +60,12 @@ class NotificationMessage::Private : public QSharedData
           && resource == other.resource
           && parentCollection == other.parentCollection
           && parentDestCollection == other.parentDestCollection
-          && mimeType == other.mimeType
+          && mimeType == other.mimeType;
+    }
+
+    bool compareWithoutOp( const Private &other ) const
+    {
+      return compareWithoutOpAndParts( other )
           && parts == other.parts;
     }
 
@@ -237,7 +243,9 @@ QString NotificationMessage::toString() const
       rv += QLatin1String( "added" );
       break;
     case Modify:
-      rv += QLatin1String( "modified" );
+      rv += QLatin1String( "modified parts (" );
+      rv += QString::fromLatin1( ImapParser::join( itemParts().toList(), ", " ) );
+      rv += QLatin1String( ")" );
       break;
     case Move:
       rv += QLatin1String( "moved" );
@@ -270,6 +278,12 @@ void NotificationMessage::appendAndCompress(NotificationMessage::List & list, co
         it = list.erase( it );
       } else
         ++it;
+    } else if ( msg.d->compareWithoutOpAndParts( *((*it).d) ) ) {
+      if ( msg.operation() == Modify && (*it).operation() == Modify && msg.type() == Item ) {
+        (*it).setItemParts( (*it).itemParts() + msg.itemParts() );
+        return;
+      } else
+        ++it;
     } else
       ++it;
   }
