@@ -33,8 +33,12 @@
 #define AKONADI_DBUS_CONTROL_SERVICE "org.freedesktop.Akonadi.Control"
 
 // Commands
+#define AKONADI_CMD_ITEMCOPY "COPY"
+#define AKONADI_CMD_ITEMCREATE "X-AKAPPEND"
 #define AKONADI_CMD_ITEMDELETE "REMOVE"
 #define AKONADI_CMD_ITEMFETCH "FETCH"
+#define AKONADI_CMD_ITEMMODIFY "STORE"
+#define AKONADI_CMD_ITEMMOVE "MOVE"
 #define AKONADI_CMD_UID "UID"
 #define AKONADI_CMD_RESOURCESELECT "RESSELECT"
 #define AKONADI_CMD_RID "RID"
@@ -44,5 +48,10 @@
 #define AKONADI_PARAM_ALLATTRIBUTES "ALLATTR"
 #define AKONADI_PARAM_CACHEONLY "CACHEONLY"
 #define AKONADI_PARAM_EXTERNALPAYLOAD "EXTERNALPAYLOAD"
+#define AKONADI_PARAM_REVISION "REV"
+#define AKONADI_PARAM_SIZE "SIZE"
+#define AKONADI_PARAM_FLAGS "FLAGS"
+#define AKONADI_PARAM_REMOTEID "REMOTEID"
+#define AKONADI_PARAM_UNDIRTY "DIRTY"
 
 #endif
