@@ -25,14 +25,13 @@
 class NotificationMessageTest : public QObject
 {
   Q_OBJECT
-  private Q_SLOTS:
+  private slots:
     void testCompress();
     void testCompress2();
     void testCompress3();
-    void testCompressWithItemParts();
     void testNoCompress();
-    void testPartModificationMerge_data();
     void testPartModificationMerge();
 };
 
+
 #endif
