@@ -21,28 +21,73 @@
 
 #include "akonadiconnection.h"
 #include "handlerhelper.h"
-#include "../../libs/imapparser_p.h"
 #include "storage/datastore.h"
 #include "storage/transaction.h"
+#include "storage/itemretriever.h"
+#include "imapstreamparser.h"
 
 using namespace Akonadi;
 
-bool ColCopy::handleLine(const QByteArray & line)
+bool ColCopy::copyCollection(const Collection & source, const Collection & target)
 {
-  QByteArray tmp;
-  int pos = ImapParser::parseString( line, tmp ); // skip tag
-  pos = ImapParser::parseString( line, tmp, pos ); // skip command
+  // copy the source collection
+  Collection col = source;
+  col.setParentId( target.id() );
+  col.setResourceId( target.resourceId() );
+  // clear remote id on inter-resource copies
+  if ( source.resourceId() != target.resourceId() )
+    col.setRemoteId( QString() );
 
-  pos = ImapParser::parseString( line, tmp, pos );
-  const Location source = HandlerHelper::collectionFromIdOrName( tmp );
+  DataStore *db = connection()->storageBackend();
+  if ( !db->appendCollection( col ) )
+    return false;
+
+  foreach ( const MimeType &mt, source.mimeTypes() ) {
+    if ( !col.addMimeType( mt ) )
+      return false;
+  }
+
+  foreach ( const CollectionAttribute &attr, source.attributes() ) {
+    CollectionAttribute newAttr = attr;
+    newAttr.setId( -1 );
+    newAttr.setCollectionId( col.id() );
+    if ( !newAttr.insert() )
+      return false;
+  }
+
+  // copy sub-collections
+  foreach ( const Collection &child, source.children() ) {
+    if ( !copyCollection( child, col ) )
+      return false;
+  }
+
+  // copy items
+  foreach ( const PimItem &item, source.items() ) {
+    if ( !copyItem( item, col ) )
+      return false;
+  }
+
+  return true;
+}
+
+bool ColCopy::parseStream()
+{
+  QByteArray tmp =  m_streamParser->readString();
+  const Collection source = HandlerHelper::collectionFromIdOrName( tmp );
   if ( !source.isValid() )
     return failureResponse( "No valid source specified" );
 
-  ImapParser::parseString( line, tmp, pos );
-  const Location target = HandlerHelper::collectionFromIdOrName( tmp );
+  tmp =  m_streamParser->readString();
+  const Collection target = HandlerHelper::collectionFromIdOrName( tmp );
   if ( !target.isValid() )
     return failureResponse( "No valid target specified" );
 
+  // retrieve all not yet cached items of the source
+  ItemRetriever retriever( connection() );
+  retriever.setCollection( source, true );
+  retriever.setRetrieveFullPayload( true );
+  retriever.exec();
+
   DataStore *store = connection()->storageBackend();
   Transaction transaction( store );
 
@@ -55,40 +100,5 @@ bool ColCopy::handleLine(const QByteArray & line)
   return successResponse( "COLCOPY complete" );
 }
 
-bool ColCopy::copyCollection(const Location & source, const Location & target)
-{
-  // copy the source collection
-  Location loc = source;
-  loc.setParentId( target.id() );
-  loc.setResourceId( target.resourceId() );
-  DataStore *db = connection()->storageBackend();
-  if ( !db->appendLocation( loc ) )
-    return false;
 
-  foreach ( const MimeType &mt, source.mimeTypes() ) {
-    if ( !loc.addMimeType( mt ) )
-      return false;
-  }
-
-  foreach ( const LocationAttribute &attr, source.attributes() ) {
-    LocationAttribute newAttr = attr;
-    newAttr.setId( -1 );
-    newAttr.setLocationId( loc.id() );
-    if ( !newAttr.insert() )
-      return false;
-  }
-
-  // copy sub-collections
-  foreach ( const Location &child, source.children() ) {
-    if ( !copyCollection( child, loc ) )
-      return false;
-  }
-
-  // copy items
-  foreach ( const PimItem &item, source.items() ) {
-    if ( !copyItem( item, loc ) )
-      return false;
-  }
-
-  return true;
-}
+#include "colcopy.moc"
