@@ -52,14 +52,11 @@ class Fetch : public Handler
     QueryBuilder buildPartQuery( const QStringList &partList, bool allPayload, bool allAttrs );
     void retrieveMissingPayloads( const QStringList &payloadList );
     void parseCommandStream();
-    void addQueryConditions( QueryBuilder &qb );
 
   private:
     QueryBuilder mItemQuery;
-    ImapSet mSet;
-    QString mRid;
     QList<QByteArray> mRequestedParts;
-    Scope::SelectionScope mScope;
+    Scope mScope;
     bool mCacheOnly;
     bool mFullPayload;
     bool mAllAttrs;
