@@ -23,9 +23,11 @@
 #include <storage/datastore.h>
 #include <storage/entity.h>
 #include <storage/transaction.h>
-#include "../../libs/imapparser_p.h"
+#include "libs/imapparser_p.h"
+#include "imapstreamparser.h"
 #include <handlerhelper.h>
 #include <response.h>
+#include <storage/itemretriever.h>
 
 using namespace Akonadi;
 
@@ -37,46 +39,59 @@ Akonadi::Modify::~ Modify()
 {
 }
 
-bool Akonadi::Modify::handleLine(const QByteArray & line)
+bool Modify::parseStream()
 {
-  int pos = line.indexOf( ' ' ) + 1; // skip tag
-  pos = line.indexOf( ' ', pos ); // skip command
-  if ( pos < 0 )
-    return failureResponse( "Invalid syntax" );
-
-  QByteArray collection;
-  pos = ImapParser::parseString( line, collection, pos );
-  Location location = HandlerHelper::collectionFromIdOrName( collection );
-  if ( !location.isValid() )
+  QByteArray collectionByteArray = m_streamParser->readString();
+  Collection collection = HandlerHelper::collectionFromIdOrName( collectionByteArray );
+  if ( !collection.isValid() )
     return failureResponse( "No such collection" );
-  if ( location.id() == 0 )
+  if ( collection.id() == 0 )
     return failureResponse( "Cannot modify root collection" );
 
+
+  //TODO: do it cleanly with the streaming parser, which doesn't have look-ahead at this moment
+  QByteArray line = m_streamParser->readUntilCommandEnd();
+  m_streamParser->insertData( "\n" );
+
+  int p = 0;
+  if ( (p = line.indexOf( "PARENT ")) > 0 ) {
+    ImapParser::parseString( line, collectionByteArray, p + 6 );
+    const Collection newParent = HandlerHelper::collectionFromIdOrName( collectionByteArray );
+    if ( newParent.isValid() && collection.parentId() != newParent.id()
+         && collection.resourceId() != newParent.resourceId() )
+    {
+      ItemRetriever retriever( connection() );
+      retriever.setCollection( collection, true );
+      retriever.setRetrieveFullPayload( true );
+      retriever.exec();
+    }
+  }
+
   DataStore *db = connection()->storageBackend();
   Transaction transaction( db );
-
+  int pos = 0;
   while ( pos < line.length() ) {
     QByteArray type;
     pos = ImapParser::parseString( line, type, pos );
     if ( type == "MIMETYPE" ) {
       QList<QByteArray> mimeTypes;
       pos = ImapParser::parseParenthesizedList( line, mimeTypes, pos );
-      if ( !db->removeMimeTypesForLocation( location.id() ) )
+      if ( !db->removeMimeTypesForCollection( collection.id() ) )
         return failureResponse( "Unable to modify collection mimetypes." );
       QStringList mts;
       foreach ( const QByteArray &ba, mimeTypes )
         mts << QString::fromLatin1(ba);
-      if ( !db->appendMimeTypeForLocation( location.id(), mts ) )
+      if ( !db->appendMimeTypeForCollection( collection.id(), mts ) )
         return failureResponse( "Unable to modify collection mimetypes." );
     } else if ( type == "CACHEPOLICY" ) {
-      pos = HandlerHelper::parseCachePolicy( line, location, pos );
-      db->notificationCollector()->collectionChanged( location );
-      if ( !location.update() )
+      pos = HandlerHelper::parseCachePolicy( line, collection, pos );
+      db->notificationCollector()->collectionChanged( collection );
+      if ( !collection.update() )
         return failureResponse( "Unable to change cache policy" );
     } else if ( type == "NAME" ) {
       QByteArray newName;
       pos = ImapParser::parseString( line, newName, pos );
-      if ( !db->renameLocation( location, location.parentId(), newName ) )
+      if ( !db->renameCollection( collection, collection.parentId(), newName ) )
         return failureResponse( "Unable to rename collection" );
     } else if ( type == "PARENT" ) {
       qint64 newParent;
@@ -84,16 +99,16 @@ bool Akonadi::Modify::handleLine(const QByteArray & line)
       pos = ImapParser::parseNumber( line, newParent, &ok, pos );
       if ( !ok )
         return failureResponse( "Invalid syntax" );
-      if ( !db->renameLocation( location, newParent, location.name() ) )
-        return failureResponse( "Unable to reparent colleciton" );
+      if ( !db->renameCollection( collection, newParent, collection.name() ) )
+        return failureResponse( "Unable to reparent collection" );
     } else if ( type == "REMOTEID" ) {
       // FIXME: missing change notification
       QString rid;
       pos = ImapParser::parseString( line, rid, pos );
-      if ( rid == location.remoteId() )
+      if ( rid == collection.remoteId() )
         continue;
-      location.setRemoteId( rid );
-      if ( !location.update() )
+      collection.setRemoteId( rid );
+      if ( !collection.update() )
         return failureResponse( "Unable to change remote identifier" );
     } else if ( type.isEmpty() ) {
       break; // input end
@@ -104,12 +119,12 @@ bool Akonadi::Modify::handleLine(const QByteArray & line)
         type = type.mid( 1 );
         removeOnly = true;
       }
-      if ( !db->removeCollectionAttribute( location, type ) )
+      if ( !db->removeCollectionAttribute( collection, type ) )
         return failureResponse( "Unable to remove custom collection attribute" );
       if ( ! removeOnly ) {
         QByteArray value;
         pos = ImapParser::parseString( line, value, pos );
-        if ( !db->addCollectionAttribute( location, type, value ) )
+        if ( !db->addCollectionAttribute( collection, type, value ) )
           return failureResponse( "Unable to add custom collection attribute" );
       }
     }
@@ -124,3 +139,5 @@ bool Akonadi::Modify::handleLine(const QByteArray & line)
   emit responseAvailable( response );
   return true;
 }
+
+#include "modify.moc"
