@@ -31,10 +31,11 @@ namespace Akonadi {
 */
 class Rename : public Handler
 {
+  Q_OBJECT
   public:
     Rename();
     ~Rename();
-    virtual bool handleLine( const QByteArray &line );
+    bool parseStream();
 };
 
 }
