@@ -239,6 +239,17 @@ bool ImapStreamParser::hasList()
   return false;
 }
 
+void ImapStreamParser::beginList()
+{
+  if ( !waitForMoreData( m_position >= m_data.length() ) )
+    throw ImapParserException("Unable to read more data");
+  stripLeadingSpaces();
+  if ( m_data[m_position] != '(' )
+    throw ImapParserException( "Stream not at a beginning of a list" );
+  ++m_position;
+  return;
+}
+
 bool ImapStreamParser::atListEnd()
 {
   if ( !waitForMoreData( m_position >= m_data.length() ) )
@@ -579,7 +590,12 @@ qint64 ImapStreamParser::readNumber( bool * ok )
     ++i;
   }
   const QByteArray tmp = m_data.mid( m_position, i - m_position );
-  result = tmp.toLongLong( ok );
+  bool success = false;
+  result = tmp.toLongLong( &success );
+  if ( ok )
+    *ok = success;
+  else if ( !success )
+    throw ImapParserException( "Unable to parse number" );
   m_position = i;
   return result;
 }
