@@ -168,7 +168,7 @@ bool DataStore::setItemFlags( const PimItem &item, const QList<Flag> &flags )
       return false;
   }
 
-  mNotificationCollector->itemChanged( item );
+  mNotificationCollector->itemChanged( item, QSet<QByteArray>() << "FLAGS" );
   return true;
 }
 
@@ -187,7 +187,7 @@ bool DataStore::appendItemFlags( const PimItem &item, const QList<Flag> &flags,
     }
   }
 
-  mNotificationCollector->itemChanged( item, col );
+  mNotificationCollector->itemChanged( item, QSet<QByteArray>() << "FLAGS", col );
   return true;
 }
 
@@ -214,7 +214,7 @@ bool DataStore::removeItemFlags( const PimItem &item, const QList<Flag> &flags )
       return false;
   }
 
-  mNotificationCollector->itemChanged( item );
+  mNotificationCollector->itemChanged( item, QSet<QByteArray>() << "FLAGS" );
   return true;
 }
 
@@ -230,7 +230,7 @@ bool DataStore::removeItemParts( const PimItem &item, const QList<QByteArray> &p
     }
   }
 
-  mNotificationCollector->itemChanged( item );
+  mNotificationCollector->itemChanged( item, parts.toSet() );
   return true;
 }
 
@@ -408,7 +408,7 @@ bool DataStore::appendPimItem( QList<Part> & parts,
                                const MimeType & mimetype,
                                const Collection & collection,
                                const QDateTime & dateTime,
-                               const QByteArray & remote_id,
+                               const QString & remote_id,
                                PimItem &pimItem )
 {
   pimItem.setMimeTypeId( mimetype.id() );
@@ -446,59 +446,6 @@ bool DataStore::appendPimItem( QList<Part> & parts,
   return true;
 }
 
-bool Akonadi::DataStore::updatePimItem(PimItem & pimItem)
-{
-  pimItem.setAtime( QDateTime::currentDateTime() );
-  if ( mSessionId != pimItem.collection().resource().name().toLatin1() )
-    pimItem.setDirty( true );
-  if ( !pimItem.update() )
-    return false;
-
-  mNotificationCollector->itemChanged( pimItem );
-  return true;
-}
-
-bool Akonadi::DataStore::updatePimItem(PimItem & pimItem, const Collection & destination)
-{
-  if ( !pimItem.isValid() || !destination.isValid() )
-    return false;
-  if ( pimItem.collectionId() == destination.id() )
-    return true;
-
-  Collection source = pimItem.collection();
-  if ( !source.isValid() )
-    return false;
-  mNotificationCollector->collectionChanged( source );
-
-  pimItem.setCollectionId( destination.id() );
-  pimItem.setAtime( QDateTime::currentDateTime() );
-  if ( mSessionId != pimItem.collection().resource().name().toLatin1() )
-    pimItem.setDirty( true );
-  if ( !pimItem.update() )
-    return false;
-
-  mNotificationCollector->collectionChanged( destination );
-  mNotificationCollector->itemMoved( pimItem, source, destination );
-  return true;
-}
-
-bool DataStore::updatePimItem(PimItem & pimItem, const QString & remoteId)
-{
-  if ( !pimItem.isValid() )
-    return false;
-  if ( pimItem.remoteId() == remoteId.toLatin1() )
-    return true;
-
-  pimItem.setRemoteId( remoteId.toLatin1() );
-  pimItem.setAtime( QDateTime::currentDateTime() );
-  if ( !pimItem.update() )
-    return false;
-  mNotificationCollector->itemChanged( pimItem );
-  return true;
-}
-
-
-
 bool DataStore::cleanupPimItem( const PimItem &item )
 {
   if ( !item.isValid() )
