@@ -47,11 +47,12 @@ void Akonadi::NotificationCollector::itemAdded( const PimItem &item,
 }
 
 void Akonadi::NotificationCollector::itemChanged( const PimItem &item,
+                                                  const QSet<QByteArray> &changedParts,
                                                   const Collection &collection,
                                                   const QString & mimeType,
                                                   const QByteArray & resource )
 {
-  itemNotification( NotificationMessage::Modify, item, collection, Collection(), mimeType, resource );
+  itemNotification( NotificationMessage::Modify, item, collection, Collection(), mimeType, resource, changedParts );
 }
 
 void Akonadi::NotificationCollector::itemMoved( const PimItem &item,
@@ -126,14 +127,16 @@ void NotificationCollector::itemNotification( NotificationMessage::Operation op,
                                               const Collection & collection,
                                               const Collection & collectionDest,
                                               const QString & mimeType,
-                                              const QByteArray & resource)
+                                              const QByteArray & resource,
+                                              const QSet<QByteArray> &parts )
 {
   NotificationMessage msg;
   msg.setSessionId( mSessionId );
   msg.setType( NotificationMessage::Item );
   msg.setOperation( op );
   msg.setUid( item.id() );
-  msg.setRemoteId( QString::fromUtf8( item.remoteId() ) );
+  msg.setRemoteId( item.remoteId() );
+  msg.setItemParts( parts );
 
   Collection col = collection;
   if ( !col.isValid() )
